package Moonshine::Bootstrap::v3::Media;

use Moonshine::Magic;

extends (
    'Moonshine::Bootstrap::Component',
    'Moonshine::Bootstrap::v3::MediaObject',   
); 

with 'Moonshine::Bootstrap::Component::Media';

1;


